@@ -1,63 +1,23 @@
 package org.apache.velocity.app;
 
 /*
- * The Apache Software License, Version 1.1
- *
- * Copyright (c) 2000-2001 The Apache Software Foundation.  All rights
- * reserved.
- *
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted provided that the following conditions
- * are met:
- *
- * 1. Redistributions of source code must retain the above copyright
- *    notice, this list of conditions and the following disclaimer.
- *
- * 2. Redistributions in binary form must reproduce the above copyright
- *    notice, this list of conditions and the following disclaimer in
- *    the documentation and/or other materials provided with the
- *    distribution.
- *
- * 3. The end-user documentation included with the redistribution, if
- *    any, must include the following acknowlegement:
- *       "This product includes software developed by the
- *        Apache Software Foundation (http://www.apache.org/)."
- *    Alternately, this acknowlegement may appear in the software itself,
- *    if and wherever such third-party acknowlegements normally appear.
- *
- * 4. The names "The Jakarta Project", "Velocity", and "Apache Software
- *    Foundation" must not be used to endorse or promote products derived
- *    from this software without prior written permission. For written
- *    permission, please contact apache@apache.org.
- *
- * 5. Products derived from this software may not be called "Apache"
- *    nor may "Apache" appear in their names without prior written
- *    permission of the Apache Group.
- *
- * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
- * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
- * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
- * DISCLAIMED.  IN NO EVENT SHALL THE APACHE SOFTWARE FOUNDATION OR
- * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
- * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
- * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
- * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
- * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
- * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
- * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
- * SUCH DAMAGE.
- * ====================================================================
- *
- * This software consists of voluntary contributions made by many
- * individuals on behalf of the Apache Software Foundation.  For more
- * information on the Apache Software Foundation, please see
- * <http://www.apache.org/>.
+ * Copyright 2000-2001,2004 The Apache Software Foundation.
+ * 
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
+ * 
+ *      http://www.apache.org/licenses/LICENSE-2.0
+ * 
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
  */
 
 import java.io.Writer;
-import java.util.Hashtable;
 import java.util.Properties;
-import java.io.ByteArrayInputStream;
 import java.io.InputStream;
 import java.io.IOException;
 import java.io.Reader;
@@ -71,9 +31,7 @@ import org.apache.velocity.Template;
 import org.apache.velocity.context.InternalContextAdapterImpl;
 import org.apache.velocity.runtime.RuntimeSingleton;
 import org.apache.velocity.runtime.RuntimeConstants;
-import org.apache.velocity.runtime.parser.ParserTreeConstants;
 import org.apache.velocity.runtime.parser.node.SimpleNode;
-import org.apache.velocity.runtime.directive.VelocimacroProxy;
 import org.apache.velocity.runtime.configuration.Configuration;
 
 import org.apache.velocity.exception.ResourceNotFoundException;
@@ -106,11 +64,10 @@ import org.apache.commons.collections.ExtendedProperties;
  * something you feel is necessary to add here, please, send a patch.
  *
  * @author <a href="mailto:geirm@optonline.net">Geir Magnusson Jr.</a>
- * @author <a href="Christoph.Reck@dlr.de">Christoph Reck</a>
- * @author <a href="jvanzyl@apache.org">Jason van Zyl</a>
- * @version $Id: Velocity.java,v 1.27 2002/01/03 12:41:19 geirm Exp $
+ * @author <a href="mailto:Christoph.Reck@dlr.de">Christoph Reck</a>
+ * @author <a href="mailto:jvanzyl@apache.org">Jason van Zyl</a>
+ * @version $Id: Velocity.java,v 1.30.4.1 2004/03/03 23:22:53 geirm Exp $
  */
-
 public class Velocity implements RuntimeConstants
 {
     /**
@@ -534,23 +491,22 @@ public class Velocity implements RuntimeConstants
     }
 
     /**
-     *   Determines if a template is accessable via the currently
-     *   configured resource loaders.
-     *   <br><br>
-     *   Note that the current implementation will <b>not</b>
-     *   change the state of the system in any real way - so this
-     *   cannot be used to pre-load the resource cache, as the
-     *   previous implementation did as a side-effect.
-     *   <br><br>
-     *   The previous implementation exhibited extreme lazyness and
-     *   sloth, and the author has been flogged.
+     * <p>Determines whether a resource is accessable via the
+     * currently configured resource loaders.  {@link
+     * org.apache.velocity.runtime.resource.Resource} is the generic
+     * description of templates, static content, etc.</p>
      *
-     *   @param templateName  name of the temlpate to search for
-     *   @return true if found, false otherwise
+     * <p>Note that the current implementation will <b>not</b> change
+     * the state of the system in any real way - so this cannot be
+     * used to pre-load the resource cache, as the previous
+     * implementation did as a side-effect.</p>
+     *
+     * @param resourceName The name of the resource to search for.
+     * @return Whether the resource was located.
      */
-    public static boolean templateExists( String templateName )
+    public static boolean resourceExists(String resourceName)
     {
-        return (RuntimeSingleton.getLoaderNameForResource(templateName) != null);
+        return (RuntimeSingleton.getLoaderNameForResource(resourceName) != null);
     }
 
     /**
@@ -618,4 +574,13 @@ public class Velocity implements RuntimeConstants
      {
         RuntimeSingleton.getRuntimeInstance().setApplicationAttribute( key, value);
      }
+
+    /**
+     * @see #resourceExists(String)
+     * @deprecated Use resourceExists(String) instead.
+     */
+    public static boolean templateExists(String resourceName)
+    {
+        return resourceExists(resourceName);
+    }
 }
