@@ -1,95 +1,35 @@
 package org.apache.velocity.runtime;
 
 /*
- * The Apache Software License, Version 1.1
- *
- * Copyright (c) 2000-2001 The Apache Software Foundation.  All rights
- * reserved.
- *
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted provided that the following conditions
- * are met:
- *
- * 1. Redistributions of source code must retain the above copyright
- *    notice, this list of conditions and the following disclaimer.
- *
- * 2. Redistributions in binary form must reproduce the above copyright
- *    notice, this list of conditions and the following disclaimer in
- *    the documentation and/or other materials provided with the
- *    distribution.
- *
- * 3. The end-user documentation included with the redistribution, if
- *    any, must include the following acknowlegement:
- *       "This product includes software developed by the
- *        Apache Software Foundation (http://www.apache.org/)."
- *    Alternately, this acknowlegement may appear in the software itself,
- *    if and wherever such third-party acknowlegements normally appear.
- *
- * 4. The names "The Jakarta Project", "Velocity", and "Apache Software
- *    Foundation" must not be used to endorse or promote products derived
- *    from this software without prior written permission. For written
- *    permission, please contact apache@apache.org.
- *
- * 5. Products derived from this software may not be called "Apache"
- *    nor may "Apache" appear in their names without prior written
- *    permission of the Apache Group.
- *
- * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
- * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
- * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
- * DISCLAIMED.  IN NO EVENT SHALL THE APACHE SOFTWARE FOUNDATION OR
- * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
- * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
- * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
- * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
- * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
- * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
- * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
- * SUCH DAMAGE.
- * ====================================================================
- *
- * This software consists of voluntary contributions made by many
- * individuals on behalf of the Apache Software Foundation.  For more
- * information on the Apache Software Foundation, please see
- * <http://www.apache.org/>.
+ * Copyright 2000-2001,2004 The Apache Software Foundation.
+ * 
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
+ * 
+ *      http://www.apache.org/licenses/LICENSE-2.0
+ * 
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
  */
 
-import java.io.InputStream;
-import java.io.File;
-import java.io.FileInputStream;
-import java.io.IOException;
 import java.io.Reader;
 
-import java.util.List;
-import java.util.ArrayList;
-import java.util.Map;
-import java.util.Hashtable;
 import java.util.Properties;
-import java.util.Stack;
-import java.util.Enumeration;
-import java.util.TreeMap;
-import java.util.Vector;
-
-import org.apache.log.Logger;
 
 import org.apache.velocity.Template;
 
-import org.apache.velocity.runtime.log.LogManager;
-import org.apache.velocity.runtime.log.LogSystem;
 
 import org.apache.velocity.runtime.parser.Parser;
 import org.apache.velocity.runtime.parser.ParseException;
 import org.apache.velocity.runtime.parser.node.SimpleNode;
 
 import org.apache.velocity.runtime.directive.Directive;
-import org.apache.velocity.runtime.VelocimacroFactory;
 
-import org.apache.velocity.runtime.resource.Resource;
 import org.apache.velocity.runtime.resource.ContentResource;
-import org.apache.velocity.runtime.resource.ResourceManager;
-
-import org.apache.velocity.util.SimplePool;
-import org.apache.velocity.util.StringUtils;
 
 import org.apache.velocity.exception.ResourceNotFoundException;
 import org.apache.velocity.exception.ParseErrorException;
@@ -97,6 +37,7 @@ import org.apache.velocity.exception.ParseErrorException;
 import org.apache.commons.collections.ExtendedProperties;
 
 import org.apache.velocity.util.introspection.Introspector;
+import org.apache.velocity.util.introspection.Uberspect;
 
 /**
  * This is the Runtime system for Velocity. It is the
@@ -117,21 +58,21 @@ import org.apache.velocity.util.introspection.Introspector;
  * the code might look something like the following:
  *
  * <pre>
- * Runtime.setProperty(Runtime.FILE_RESOURCE_LOADER_PATH, templatePath);
- * Runtime.setProperty(Runtime.RUNTIME_LOG, pathToVelocityLog);
- * Runtime.init();
+ * RuntimeSingleton.setProperty(RuntimeConstants.FILE_RESOURCE_LOADER_PATH, templatePath);
+ * RuntimeSingleton.setProperty(RuntimeConstants.RUNTIME_LOG, pathToVelocityLog);
+ * RuntimeSingleton.init();
  * </pre>
  *
  * <pre>
  * -----------------------------------------------------------------------
  * N O T E S  O N  R U N T I M E  I N I T I A L I Z A T I O N
  * -----------------------------------------------------------------------
- * Runtime.init()
+ * RuntimeSingleton.init()
  * 
  * If Runtime.init() is called by itself the Runtime will
  * initialize with a set of default values.
  * -----------------------------------------------------------------------
- * Runtime.init(String/Properties)
+ * RuntimeSingleton.init(String/Properties)
  *
  * In this case the default velocity properties are layed down
  * first to provide a solid base, then any properties provided
@@ -143,13 +84,17 @@ import org.apache.velocity.util.introspection.Introspector;
  * @author <a href="mailto:jvanzyl@apache.org">Jason van Zyl</a>
  * @author <a href="mailto:jlb@houseofdistraction.com">Jeff Bowden</a>
  * @author <a href="mailto:geirm@optonline.net">Geir Magusson Jr.</a>
- * @version $Id: RuntimeSingleton.java,v 1.4 2001/10/31 02:59:28 geirm Exp $
+ * @author <a href="mailto:dlr@finemaltcoding.com">Daniel Rall</a>
+ *
+ * @see org.apache.velocity.runtime.RuntimeInstance
+ *
+ * @version $Id: RuntimeSingleton.java,v 1.7.4.1 2004/03/03 23:22:55 geirm Exp $
  */
 public class RuntimeSingleton implements RuntimeConstants
 {
     private static RuntimeInstance ri = new RuntimeInstance();
 
-    /*
+    /**
      * This is the primary initialization method in the Velocity
      * Runtime. The systems that are setup/initialized here are
      * as follows:
@@ -169,9 +114,12 @@ public class RuntimeSingleton implements RuntimeConstants
         ri.init();
     }
 
+    /**
+     * @return The RuntimeInstance used by this wrapper.
+     */
     public static RuntimeServices getRuntimeServices()
     {
-        return (RuntimeServices) ri;
+        return ri;
     }
   
 
@@ -586,12 +534,24 @@ public class RuntimeSingleton implements RuntimeConstants
     }
     
     /**
-    *  returns the RuntimeInstance object for this singleton
-    *  For internal use only :)
-    *
-    *  @return RuntimeInstance the RuntimeInstance used by this Singleton
-    *                           instance
-    */
+     * @see org.apache.velocity.runtime.RuntimeServices#getApplicationAttribute(Object)
+     */
+    public static Object getApplicationAttribute(Object key)
+    {
+        return ri.getApplicationAttribute(key);
+    }
+
+    /**
+     * @see org.apache.velocity.runtime.RuntimeServices#getUberspect()
+     */
+    public static Uberspect getUberspect()
+    {
+        return ri.getUberspect();
+    }
+
+    /**
+     * @deprecated Use getRuntimeServices() instead.
+     */
     public static RuntimeInstance getRuntimeInstance()
     {
         return ri;
