@@ -1,83 +1,42 @@
 package org.apache.velocity.runtime.parser.node;
 
 /*
- * The Apache Software License, Version 1.1
- *
- * Copyright (c) 2000-2001 The Apache Software Foundation.  All rights
- * reserved.
- *
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted provided that the following conditions
- * are met:
- *
- * 1. Redistributions of source code must retain the above copyright
- *    notice, this list of conditions and the following disclaimer.
- *
- * 2. Redistributions in binary form must reproduce the above copyright
- *    notice, this list of conditions and the following disclaimer in
- *    the documentation and/or other materials provided with the
- *    distribution.
- *
- * 3. The end-user documentation included with the redistribution, if
- *    any, must include the following acknowlegement:
- *       "This product includes software developed by the
- *        Apache Software Foundation (http://www.apache.org/)."
- *    Alternately, this acknowlegement may appear in the software itself,
- *    if and wherever such third-party acknowlegements normally appear.
- *
- * 4. The names "The Jakarta Project", "Velocity", and "Apache Software
- *    Foundation" must not be used to endorse or promote products derived
- *    from this software without prior written permission. For written
- *    permission, please contact apache@apache.org.
- *
- * 5. Products derived from this software may not be called "Apache"
- *    nor may "Apache" appear in their names without prior written
- *    permission of the Apache Group.
- *
- * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
- * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
- * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
- * DISCLAIMED.  IN NO EVENT SHALL THE APACHE SOFTWARE FOUNDATION OR
- * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
- * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
- * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
- * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
- * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
- * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
- * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
- * SUCH DAMAGE.
- * ====================================================================
- *
- * This software consists of voluntary contributions made by many
- * individuals on behalf of the Apache Software Foundation.  For more
- * information on the Apache Software Foundation, please see
- * <http://www.apache.org/>.
+ * Copyright 2000-2002,2004 The Apache Software Foundation.
+ * 
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
+ * 
+ *      http://www.apache.org/licenses/LICENSE-2.0
+ * 
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
  */
 
 import java.io.Writer;
 import java.io.IOException;
-import java.util.Map;
-import java.lang.reflect.Method;
 import java.lang.reflect.InvocationTargetException;
 
 import org.apache.velocity.context.Context;
 import org.apache.velocity.context.InternalContextAdapter;
-import org.apache.velocity.runtime.RuntimeServices;
 import org.apache.velocity.runtime.RuntimeConstants;
 import org.apache.velocity.runtime.exception.ReferenceException;
 import org.apache.velocity.runtime.parser.*;
 
-import org.apache.velocity.util.introspection.Introspector;
+import org.apache.velocity.util.introspection.VelPropertySet;
+import org.apache.velocity.util.introspection.Info;
 
 import org.apache.velocity.exception.MethodInvocationException;
 
 import org.apache.velocity.app.event.EventCartridge;
-import org.apache.velocity.app.event.ReferenceInsertionEventHandler;
 
 /**
  * This class is responsible for handling the references in
  * VTL ($foo).
- * 
+ *
  * Please look at the Parser.jjt file which is
  * what controls the generation of this class.
  *
@@ -85,7 +44,7 @@ import org.apache.velocity.app.event.ReferenceInsertionEventHandler;
  * @author <a href="mailto:geirm@optonline.net">Geir Magnusson Jr.</a>
  * @author <a href="mailto:Christoph.Reck@dlr.de">Christoph Reck</a>
  * @author <a href="mailto:kjohnson@transparent.com>Kent Johnson</a>
- * @version $Id: ASTReference.java,v 1.43 2002/02/23 11:00:40 geirm Exp $ 
+ * @version $Id: ASTReference.java,v 1.49.4.1 2004/03/03 23:22:59 geirm Exp $
 */
 public class ASTReference extends SimpleNode
 {
@@ -94,7 +53,7 @@ public class ASTReference extends SimpleNode
     private static final int FORMAL_REFERENCE = 2;
     private static final int QUIET_REFERENCE = 3;
     private static final int RUNT = 4;
-    
+
     private int referenceType;
     private String nullString;
     private String rootString;
@@ -103,11 +62,13 @@ public class ASTReference extends SimpleNode
     private String escPrefix = "";
     private String morePrefix = "";
     private String identifier = "";
-    
+
     private String literal = null;
 
     private int numChildren = 0;
 
+    protected Info uberInfo;
+
     public ASTReference(int id)
     {
         super(id);
@@ -124,14 +85,14 @@ public class ASTReference extends SimpleNode
         return visitor.visit(this, data);
     }
 
-    public Object init( InternalContextAdapter context, Object data) 
+    public Object init(InternalContextAdapter context, Object data)
         throws Exception
     {
         /*
          *  init our children
          */
 
-        super.init( context, data );
+        super.init(context, data);
 
         /*
          *  the only thing we can do in init() is getRoot()
@@ -142,7 +103,7 @@ public class ASTReference extends SimpleNode
         rootString = getRoot();
 
         numChildren = jjtGetNumChildren();
-        
+
         /*
          * and if appropriate...
          */
@@ -152,9 +113,16 @@ public class ASTReference extends SimpleNode
             identifier = jjtGetChild(numChildren - 1).getFirstToken().image;
         }
 
+        /*
+         * make an uberinfo - saves new's later on
+         */
+
+        uberInfo = new Info(context.getCurrentTemplateName(),
+                getLine(),getColumn());
+
         return data;
-    }        
-    
+    }
+
     /**
      *  Returns the 'root string', the reference key
      */
@@ -162,7 +130,7 @@ public class ASTReference extends SimpleNode
      {
         return rootString;
      }
-     
+
     /**
      *   gets an Object that 'is' the value of the reference
      *
@@ -171,9 +139,9 @@ public class ASTReference extends SimpleNode
      */
     public Object execute(Object o, InternalContextAdapter context)
         throws MethodInvocationException
-    {   
+    {
 
-        if ( referenceType == RUNT )
+        if (referenceType == RUNT)
             return null;
 
         /*
@@ -181,11 +149,11 @@ public class ASTReference extends SimpleNode
          */
 
         Object result = getVariableValue(context, rootString);
-       
+
         if (result == null)
         {
             return null;
-        }            
+        }
 
         /*
          * Iteratively work 'down' (it's flat...) the reference
@@ -199,33 +167,35 @@ public class ASTReference extends SimpleNode
          * when we find a null value and return the null
          * so the error gets logged.
          */
-        
-        try 
+
+        try
         {
             for (int i = 0; i < numChildren; i++)
             {
                 result = jjtGetChild(i).execute(result,context);
-            
+
                 if (result == null)
                 {
                     return null;
-                }         
+                }
             }
-            
+
             return result;
         }
-        catch( MethodInvocationException mie)
+        catch(MethodInvocationException mie)
         {
             /*
              *  someone tossed their cookies
              */
 
-            rsvc.error("Method " + mie.getMethodName() + " threw exception for reference $" 
-                          + rootString 
-                          + " in template " + context.getCurrentTemplateName()
-                          + " at " +  " [" + this.getLine() + "," + this.getColumn() + "]");
+            rsvc.error("Method " + mie.getMethodName()
+                        + " threw exception for reference $"
+                        + rootString
+                        + " in template " + context.getCurrentTemplateName()
+                        + " at " +  " [" + this.getLine() + ","
+                        + this.getColumn() + "]");
 
-            mie.setReferenceName( rootString );
+            mie.setReferenceName(rootString);
             throw mie;
         }
     }
@@ -237,38 +207,38 @@ public class ASTReference extends SimpleNode
      *  @param context  context of data to use in getting value
      *  @param writer   writer to render to
      */
-    public boolean render( InternalContextAdapter context, Writer writer)
+    public boolean render(InternalContextAdapter context, Writer writer)
         throws IOException, MethodInvocationException
     {
 
-        if (referenceType == RUNT )
+        if (referenceType == RUNT)
         {
-            writer.write( rootString );
+            writer.write(rootString);
             return true;
         }
 
         Object value = execute(null, context);
-        
+
         /*
          *  if this reference is escaped (\$foo) then we want to do one of two things :
          *  1) if this is a reference in the context, then we want to print $foo
          *  2) if not, then \$foo  (its considered shmoo, not VTL)
          */
 
-        if ( escaped )
+        if (escaped)
         {
-            if ( value == null )
+            if (value == null)
             {
-                writer.write( escPrefix );
-                writer.write( "\\" );
-                writer.write( nullString );
+                writer.write(escPrefix);
+                writer.write("\\");
+                writer.write(nullString);
             }
             else
             {
-                writer.write( escPrefix );
-                writer.write( nullString );
+                writer.write(escPrefix);
+                writer.write(nullString);
             }
-        
+
             return true;
         }
 
@@ -282,7 +252,7 @@ public class ASTReference extends SimpleNode
 
         if (ec != null)
         {
-            value =  ec.referenceInsert( nullString, value );
+            value =  ec.referenceInsert(literal(), value);
         }
 
         /*
@@ -291,21 +261,21 @@ public class ASTReference extends SimpleNode
 
         if (value == null)
         {
-            /* 
+            /*
              *  write prefix twice, because it's shmoo, so the \ don't escape each other...
              */
-              
-            writer.write( escPrefix );
-            writer.write( escPrefix );
-            writer.write( morePrefix );          
-            writer.write( nullString );
-          
-            if (referenceType != QUIET_REFERENCE 
-                && rsvc.getBoolean( 
-                                      RuntimeConstants.RUNTIME_LOG_REFERENCE_LOG_INVALID, true) )
+
+            writer.write(escPrefix);
+            writer.write(escPrefix);
+            writer.write(morePrefix);
+            writer.write(nullString);
+
+            if (referenceType != QUIET_REFERENCE
+                && rsvc.getBoolean(RuntimeConstants.RUNTIME_LOG_REFERENCE_LOG_INVALID,
+                        true))
             {
-               rsvc.warn(new ReferenceException("reference : template = " 
-                                                    + context.getCurrentTemplateName(), this));
+               rsvc.warn(new ReferenceException("reference : template = "
+                                + context.getCurrentTemplateName(), this));
             }
 
             return true;
@@ -316,14 +286,14 @@ public class ASTReference extends SimpleNode
              *  non-null processing
              */
 
-            writer.write( escPrefix );
-            writer.write( morePrefix );
-            writer.write( value.toString() );
-        
+            writer.write(escPrefix);
+            writer.write(morePrefix);
+            writer.write(value.toString());
+
             return true;
         }
     }
-       
+
     /**
      *   Computes boolean value of this reference
      *   Returns the actual value of reference return type
@@ -331,11 +301,11 @@ public class ASTReference extends SimpleNode
      *
      *   @param context context to compute value with
      */
-    public boolean evaluate( InternalContextAdapter context)
+    public boolean evaluate(InternalContextAdapter context)
         throws MethodInvocationException
     {
         Object value = execute(null, context);
-        
+
         if (value == null)
         {
             return false;
@@ -351,10 +321,10 @@ public class ASTReference extends SimpleNode
             return true;
     }
 
-    public Object value( InternalContextAdapter context)
+    public Object value(InternalContextAdapter context)
         throws MethodInvocationException
     {
-        return ( computableReference ? execute(null, context) : null );
+        return (computableReference ? execute(null, context) : null);
     }
 
     /**
@@ -370,6 +340,12 @@ public class ASTReference extends SimpleNode
     public boolean setValue( InternalContextAdapter context, Object value)
       throws MethodInvocationException
     {
+        if (jjtGetNumChildren() == 0)
+        {
+            context.put(rootString, value);
+            return true;
+        }
+
         /*
          *  The rootOfIntrospection is the object we will
          *  retrieve from the Context. This is the base
@@ -377,13 +353,14 @@ public class ASTReference extends SimpleNode
          */
 
         Object result = getVariableValue(context, rootString);
-        
+
         if (result == null)
         {
-            rsvc.error(new ReferenceException("reference set : template = " + context.getCurrentTemplateName(), this));
+            rsvc.error(new ReferenceException("reference set : template = "
+                    + context.getCurrentTemplateName(), this));
             return false;
-        }                          
-        
+        }
+
         /*
          * How many child nodes do we have?
          */
@@ -391,13 +368,14 @@ public class ASTReference extends SimpleNode
         for (int i = 0; i < numChildren - 1; i++)
         {
             result = jjtGetChild(i).execute(result, context);
-            
+
             if (result == null)
             {
-                rsvc.error(new ReferenceException("reference set : template = " + context.getCurrentTemplateName(), this));
+                rsvc.error(new ReferenceException("reference set : template = "
+                        + context.getCurrentTemplateName(), this));
                 return false;
-            }                          
-        }            
+            }
+        }
 
         /*
          *  We support two ways of setting the value in a #set($ref.foo = $value ) :
@@ -407,106 +385,39 @@ public class ASTReference extends SimpleNode
 
         try
         {
-            /*
-             *  first, we introspect for the set<identifier> setter method
-             */
+            VelPropertySet vs =
+                    rsvc.getUberspect().getPropertySet(result, identifier,
+                            value, uberInfo);
 
-            Object[] params = { value };
-
-            Class c = result.getClass();
-            Method m = null;
-
-            try
-            {
-                m = rsvc.getIntrospector().getMethod( c, "set" + identifier, params);
-
-                if (m == null)
-                {
-                    throw new NoSuchMethodException();
-                }
-            }
-            catch( NoSuchMethodException nsme2)
-            {
-                StringBuffer sb = new StringBuffer( "set" );
-                sb.append( identifier );
-
-                if(  Character.isLowerCase( sb.charAt(3)))
-                {
-                    sb.setCharAt( 3 ,  Character.toUpperCase( sb.charAt( 3 ) ) );
-                }
-                else
-                {
-                    sb.setCharAt( 3 ,  Character.toLowerCase( sb.charAt( 3 ) ) );
-                }
-               
-                m = rsvc.getIntrospector().getMethod( c, sb.toString(), params);
-
-                if (m == null)
-                {
-                    throw new NoSuchMethodException();
-                }
-            }
-
-            /*
-             *  and if we get here, getMethod() didn't chuck an exception...
-             */
-            
-            Object[] args = { value };
-            m.invoke(result, args);
-        }
-        catch (NoSuchMethodException nsme)
-        {
-            /*
-             *  right now, we only support the Map interface
-             */
-
-            if (result instanceof Map)
-            {
-                try
-                {
-                    ((Map) result).put(identifier, value);
-                }
-                catch (Exception ex)
-                {
-                    rsvc.error("ASTReference Map.put : exception : " + ex 
-                                  + " template = " + context.getCurrentTemplateName() 
-                                  + " [" + this.getLine() + "," + this.getColumn() + "]");
-                    return false;
-                }
-            }
-            else
-            {
-                rsvc.error("ASTReference : cannot find " + identifier + " as settable property or key to Map in"
-                              + " template = " + context.getCurrentTemplateName() 
-                              + " [" + this.getLine() + "," + this.getColumn() + "]");
+            if (vs == null)
                 return false;
-                
-            }
+
+            vs.invoke(result, value);
         }
-        catch( InvocationTargetException ite )
+        catch(InvocationTargetException ite)
         {
             /*
-             *  this is possible 
+             *  this is possible
              */
 
-            throw  new MethodInvocationException( 
-                "ASTReference : Invocation of method '" 
+            throw  new MethodInvocationException(
+                "ASTReference : Invocation of method '"
                 + identifier + "' in  " + result.getClass()
-                + " threw exception " 
-                + ite.getTargetException().getClass(), 
+                + " threw exception "
+                + ite.getTargetException().getClass(),
                ite.getTargetException(), identifier );
         }
-        catch( Exception e )
+        catch(Exception e)
         {
             /*
              *  maybe a security exception?
              */
-            rsvc.error("ASTReference setValue() : exception : " + e 
-                                  + " template = " + context.getCurrentTemplateName() 
+            rsvc.error("ASTReference setValue() : exception : " + e
+                                  + " template = " + context.getCurrentTemplateName()
                                   + " [" + this.getLine() + "," + this.getColumn() + "]");
             return false;
          }
-        
+
         return true;
     }
 
@@ -515,7 +426,7 @@ public class ASTReference extends SimpleNode
         Token t = getFirstToken();
 
         /*
-         *  we have a special case where something like 
+         *  we have a special case where something like
          *  $(\\)*!, where the user want's to see something
          *  like $!blargh in the output, but the ! prevents it from showing.
          *  I think that at this point, this isn't a reference.
@@ -525,17 +436,17 @@ public class ASTReference extends SimpleNode
 
         int slashbang = t.image.indexOf("\\!");
 
-        if ( slashbang != -1 )
+        if (slashbang != -1)
         {
             /*
-             *  lets do all the work here.  I would argue that if this occurrs, it's 
-             *  not a reference at all, so preceeding \ characters in front of the $
-             *  are just schmoo.  So we just do the escape processing trick (even | odd)
-             *  and move on.  This kind of breaks the rule pattern of $ and # but '!' really
-             *  tosses a wrench into things.
+             *  lets do all the work here.  I would argue that if this occurrs,
+             *  it's not a reference at all, so preceeding \ characters in front
+             *  of the $ are just schmoo.  So we just do the escape processing
+             *  trick (even | odd) and move on.  This kind of breaks the rule
+             *  pattern of $ and # but '!' really tosses a wrench into things.
              */
 
-             /* 
+             /*
               *  count the escapes : even # -> not escaped, odd -> escaped
               */
 
@@ -547,34 +458,40 @@ public class ASTReference extends SimpleNode
             if (i == -1)
             {
                 /* yikes! */
-                rsvc.error("ASTReference.getRoot() : internal error : no $ found for slashbang.");
+                rsvc.error("ASTReference.getRoot() : internal error : "
+                            + "no $ found for slashbang.");
                 computableReference = false;
                 nullString = t.image;
                 return nullString;
             }
 
-            while( i < len && t.image.charAt(i) != '\\')
+            while (i < len && t.image.charAt(i) != '\\')
+            {
                 i++;
+            }
 
             /*  ok, i is the first \ char */
 
             int start = i;
             int count = 0;
- 
-            while( i < len && t.image.charAt(i++) == '\\' )
+
+            while (i < len && t.image.charAt(i++) == '\\')
+            {
                 count++;
-           
+            }
+
             /*
-             *  now construct the output string.  We really don't care about leading 
-             *  slashes as this is not a reference.  It's quasi-schmoo
+             *  now construct the output string.  We really don't care about
+             *  leading  slashes as this is not a reference.  It's quasi-schmoo
              */
 
-            nullString = t.image.substring(0,start); // prefix up to the first 
+            nullString = t.image.substring(0,start); // prefix up to the first
             nullString += t.image.substring(start, start + count-1 ); // get the slashes
-            nullString += t.image.substring(start+count); // and the rest, including the 
+            nullString += t.image.substring(start+count); // and the rest, including the
 
             /*
-             *  this isn't a valid reference, so lets short circuit the value and set calcs
+             *  this isn't a valid reference, so lets short circuit the value
+             *  and set calcs
              */
 
             computableReference = false;
@@ -584,32 +501,33 @@ public class ASTReference extends SimpleNode
 
         /*
          *  we need to see if this reference is escaped.  if so
-         *  we will clean off the leading \'s and let the 
+         *  we will clean off the leading \'s and let the
          *  regular behavior determine if we should output this
          *  as \$foo or $foo later on in render(). Lazyness..
          */
-      
+
         escaped = false;
 
-        if ( t.image.startsWith("\\"))
+        if (t.image.startsWith("\\"))
         {
-            /* 
+            /*
              *  count the escapes : even # -> not escaped, odd -> escaped
              */
 
             int i = 0;
             int len = t.image.length();
 
-            while( i < len && t.image.charAt(i) == '\\' )
+            while (i < len && t.image.charAt(i) == '\\')
+            {
                 i++;
+            }
 
- 
-            if ( (i % 2) != 0 )                
+            if ((i % 2) != 0)
                 escaped = true;
 
             if (i > 0)
                 escPrefix = t.image.substring(0, i / 2 );
-                                     
+
             t.image = t.image.substring(i);
         }
 
@@ -618,43 +536,43 @@ public class ASTReference extends SimpleNode
          *  and snip it off, except for the
          *  last $
          */
-              
+
         int loc1 = t.image.lastIndexOf('$');
-             
+
         /*
          *  if we have extra stuff, loc > 0
-         *  ex. '#$foo' so attach that to 
+         *  ex. '#$foo' so attach that to
          *  the prefix.
          */
-        if( loc1 > 0)
+        if (loc1 > 0)
         {
             morePrefix = morePrefix + t.image.substring(0, loc1);
             t.image = t.image.substring(loc1);
         }
-        
+
         /*
-         *  Now it should be clean. Get the literal in case this reference 
+         *  Now it should be clean. Get the literal in case this reference
          *  isn't backed by the context at runtime, and then figure out what
          *  we are working with.
          */
 
         nullString = literal();
-        
+
         if (t.image.startsWith("$!"))
         {
             referenceType = QUIET_REFERENCE;
- 
+
             /*
              *  only if we aren't escaped do we want to null the output
              */
 
             if (!escaped)
                 nullString = "";
- 
+
             if (t.image.startsWith("$!{"))
             {
                 /*
-                 *  ex : $!{provider.Title} 
+                 *  ex : $!{provider.Title}
                  */
 
                 return t.next.image;
@@ -664,7 +582,7 @@ public class ASTReference extends SimpleNode
                 /*
                  *  ex : $!provider.Title
                  */
- 
+
                 return t.image.substring(2);
             }
         }
@@ -676,28 +594,28 @@ public class ASTReference extends SimpleNode
 
             referenceType = FORMAL_REFERENCE;
             return t.next.image;
-        }            
-        else if ( t.image.startsWith("$") )
+        }
+        else if (t.image.startsWith("$"))
         {
             /*
-             *  just nip off the '$' so we have 
+             *  just nip off the '$' so we have
              *  the root
              */
-             
-            referenceType = NORMAL_REFERENCE;   
+
+            referenceType = NORMAL_REFERENCE;
             return t.image.substring(1);
         }
         else
         {
             /*
              * this is a 'RUNT', which can happen in certain circumstances where
-             *  the parser is fooled into believeing that an IDENTIFIER is a real 
-             *  reference.  Another 'dreaded' MORE hack :). 
+             *  the parser is fooled into believeing that an IDENTIFIER is a real
+             *  reference.  Another 'dreaded' MORE hack :).
              */
             referenceType = RUNT;
             return t.image;
         }
-                
+
     }
 
     public Object getVariableValue(Context context, String variable)
@@ -718,7 +636,7 @@ public class ASTReference extends SimpleNode
      *
      *  @param literal String to render to when null
      */
-    public void setLiteral( String literal )
+    public void setLiteral(String literal)
     {
         /*
          * do only once
@@ -730,7 +648,7 @@ public class ASTReference extends SimpleNode
 
     /**
      *  Override of the SimpleNode method literal()
-     *  Returns the literal representation of the 
+     *  Returns the literal representation of the
      *  node.  Should be something like
      *  $<token>.
      */
@@ -742,4 +660,3 @@ public class ASTReference extends SimpleNode
         return super.literal();
     }
 }
-
